@@ -10,7 +10,7 @@ import re
 import time
 from collections import defaultdict
 
-import requests
+import httpx
 from poseidon_core import __version__
 from poseidon_core.constants import NO_DATA
 from poseidon_core.helpers.config import Config
@@ -66,6 +66,9 @@ class Prometheus():
         self.prom_metrics['last_rabbitmq_routing_key_time'] = Gauge('poseidon_last_rabbitmq_routing_key_time',
                                                                     'Epoch time when last received a RabbitMQ message',
                                                                     ['routing_key'])
+        self.prom_metrics['last_tool_result_time'] = Gauge('poseidon_last_tool_result_time',
+                                                           'Epoch time when last received a tool result message',
+                                                           ['tool'])
         self.prom_metrics['ncapture_count'] = Counter(
             'poseidon_ncapture_count', 'Number of times ncapture ran')
         self.prom_metrics['method_runtime_secs'] = Summary('poseidon_method_runtime_secs',
@@ -263,7 +266,7 @@ class Prometheus():
         payload = {'query': var, 'start': start_time_str,
                    'end': end_time_str, 'step': step}
         try:
-            response = requests.get(
+            response = httpx.get(
                 'http://%s/api/v1/query_range' % self.prometheus_addr, params=payload)
         except Exception:
             return []
